@@ -734,9 +734,12 @@ class BaseExperiment:
                 raise ValueError("Wrong file extension {} for the checkpoint. It should be in {}".format(ckpt_extension_type, extension_candidates))
             if ckpt_extension_type == ".sav":
                 best_ckpt = pickle.load(open(ckpt_dir, 'rb'))
-            else:
+            elif BaseNet in inspect.getmro(model_type) or ConvNet in inspect.getmro(model_type):
                 best_ckpt = eval(model_type).load_from_checkpoint(dims=self.dims, n_classes=self.n_classes, checkpoint_path=ckpt_dir)
-            
+            elif pl.LightningModule in inspect.getmro(model_type):
+                best_ckpt = eval(model_type).load_from_checkpoint(checkpoint_path=ckpt_dir)
+            else:
+                raise AssertionError
             return best_ckpt, info
         else:
             ckpt_path = self.log_path + '/checkpoints/' + model_type + "/" + best_model_metadata + "/" + best_version
